@@ -8,7 +8,7 @@ from . import TransportProperties
 from . import Constants
 from .UnitConverter import UnitConverter
 from . import IAPWS_R14
-from . import IAPWS_R15
+
 
 class XSteam(object):
     """Main pyXSteam object. Abstract of all other functions to allow auto selection of
@@ -442,16 +442,16 @@ class XSteam(object):
         elif region == 3:
             return self.unitConverter.fromSIunit_h(Region3.h3_rhoT(rho, Region3.T3_prho(p, rho)))
         elif region == 4:
-                if p < 16.529:
-                    vV = Region2.v2_pT(p, Region4.T4_p(p))
-                    vL = Region1.v1_pT(p, Region4.T4_p(p))
-                else:
-                    vV = Region3.v3_ph(p, Region4.h4V_p(p))
-                    vL = Region3.v3_ph(p, Region4.h4L_p(p))
-                hV = Region4.h4V_p(p)
-                hL = Region4.h4L_p(p)
-                x = (1 / rho - vL) / (vV - vL)
-                return self.unitConverter.fromSIunit_h((1 - x) * hL + x * hV)
+            if p < 16.529:
+                vV = Region2.v2_pT(p, Region4.T4_p(p))
+                vL = Region1.v1_pT(p, Region4.T4_p(p))
+            else:
+                vV = Region3.v3_ph(p, Region4.h4V_p(p))
+                vL = Region3.v3_ph(p, Region4.h4L_p(p))
+            hV = Region4.h4V_p(p)
+            hL = Region4.h4L_p(p)
+            x = (1 / rho - vL) / (vV - vL)
+            return self.unitConverter.fromSIunit_h((1 - x) * hL + x * hV)
         elif region == 5:
             return self.unitConverter.fromSIunit_h(Region5.h5_pT(p, Region5.T5_prho(p, rho)))
         else:
@@ -1793,13 +1793,12 @@ class XSteam(object):
         rho = 1 / v
         return self.unitConverter.fromSIunit_tc(TransportProperties.tc_ptrho(p, T, rho))
 
-    def tc_pt(self, p, t, mode=None):
+    def tc_pt(self, p, t):
         """Thermal conductivity as a function of pressure and temperature
 
         Args:
             p (float): preasure value
             t (float): temperature value
-            mode (optional): swith to using formular from R15
 
         Returns:
             tc (float): thermal conductivity
@@ -1813,14 +1812,7 @@ class XSteam(object):
         v = self.unitConverter.toSIunit_v(v)
         rho = 1 / v
 
-        if mode is None:
-            tc = self.unitConverter.fromSIunit_tc(TransportProperties.tc_ptrho(p, T, rho))
-        else:
-            cp = self.Cp_pt(p, t)
-            cv = self.Cv_pt(p, t)
-            my = self.my_pt(p, t)
-            tc = self.unitConverter.fromSIunit_tc(IAPWS_R15.tc_ptrhocp_R15(p, T, rho, my, cp, cv))
-        return tc
+        return self.unitConverter.fromSIunit_tc(TransportProperties.tc_ptrho(p, T, rho))
 
     def tc_ph(self, p, h):
         """Thermal conductivity as a function of pressure and enthalpy
@@ -1985,13 +1977,13 @@ class XSteam(object):
                 return float("NaN")
             elif T >= 256.164 and T < 273.31:
                 self.logger.debug('chose ice type V based on temperature')
-                return self.unitConverter.fromSIunit_p(R14.pmelt_T_iceV(T))
+                return self.unitConverter.fromSIunit_p(IAPWS_R14.pmelt_T_iceV(T))
             elif T >= 273.31 and T < 355:
                 self.logger.debug('chose ice type VI based on temperature')
-                return self.unitConverter.fromSIunit_p(R14.pmelt_T_iceVI(T))
+                return self.unitConverter.fromSIunit_p(IAPWS_R14.pmelt_T_iceVI(T))
             elif T >= 355 and T < 751:
                 self.logger.debug('chose ice type VII based on temperature')
-                return self.unitConverter.fromSIunit_p(R14.pmelt_T_iceVII(T))
+                return self.unitConverter.fromSIunit_p(IAPWS_R14.pmelt_T_iceVII(T))
             else:
                 self.logger.warning('temperature out of range')
                 return float("NaN")
